@@ -12,13 +12,9 @@
          warning("violates rule of thumb about > 5 expected in each cell")
      cc <- tabulate(x, max.bin)
      chisqstat <- sum((cc - ecc)^2 / ecc)
-     cat("chi squared statistic =", chisqstat, "\n")
-     cat("degrees of freedom =", length(ecc) - 1, "\n")
-     cat("p-value =", pchisq(chisqstat, length(ecc) - 1, lower.tail = FALSE),
-         "\n")
-     foo <- rbind(cc, ecc)
-     dimnames(foo) <- list(c("observed", "expected"), as.character(xx))
-     print(foo)
+     pval <- pchisq(chisqstat, length(ecc) - 1, lower.tail = FALSE)
+     list(chisqstat = chisqstat, df = length(ecc) - 1, pval = pval,
+             observed = cc, expected = ecc, x = xx)
  }
 
  set.seed(42)
@@ -26,20 +22,20 @@
 
  mu <- 2.0
  x <- rnzp(nsim, mu)
- do.chisq.test(x, mu, 8)
+ chisqout1 <- do.chisq.test(x, mu, 8)
 
  mu <- 1.0
  x <- rnzp(nsim, mu)
- do.chisq.test(x, mu, 5)
+ chisqout2 <- do.chisq.test(x, mu, 5)
 
  mu <- 0.5
  x <- rnzp(nsim, mu)
- do.chisq.test(x, mu, 4)
+ chisqout3 <- do.chisq.test(x, mu, 4)
 
  nsim <- 1e6
  mu <- 0.05
  x <- rnzp(nsim, mu)
- do.chisq.test(x, mu, 4)
+ chisqout4 <- do.chisq.test(x, mu, 4)
 
  # nsim <- 1e7
  # mu <- 0.005
@@ -58,4 +54,14 @@
              my.x[i] <- my.x[i] + rnzp(1, mu)
  all.equal(x, my.x)
 
+ foo <- new.env(parent = emptyenv())
+ bar <- suppressWarnings(try(load("nzp.rda", foo), silent = TRUE))
+ if (inherits(bar, "try-error")) {
+     save(list = paste("chisqout", 1:4, sep = ""), file = "nzp.rda")
+ } else {
+     print(all.equal(chisqout1, foo$chisqout1))
+     print(all.equal(chisqout2, foo$chisqout2))
+     print(all.equal(chisqout3, foo$chisqout3))
+     print(all.equal(chisqout4, foo$chisqout4))
+ }
 
